@@ -32,6 +32,7 @@ import javax.ws.rs.QueryParam;
 import javax.ws.rs.core.MultivaluedMap;
 import javax.ws.rs.core.Response;
 import javax.ws.rs.core.UriBuilder;
+import javax.ws.rs.core.UriBuilderException;
 
 import org.apache.cxf.jaxrs.resources.Book;
 import org.apache.cxf.jaxrs.resources.BookStore;
@@ -43,6 +44,7 @@ import org.junit.Test;
 import org.junit.rules.ExpectedException;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertThrows;
 import static org.junit.Assert.fail;
 
 public class UriBuilderImplTest {
@@ -1698,6 +1700,30 @@ public class UriBuilderImplTest {
         assertEquals(url, uri.toString());
     }
 
+    @Test
+    public void testExpandQueryValueAsCollection() {
+        Map<String, Object> props = Collections.singletonMap("expand.query.value.as.collection", true);
+        URI uri = new UriBuilderImpl(props).queryParam("foo", "v1", "v2", "v3").build();
+        assertEquals("foo=v1,v2,v3", uri.getQuery());
+    }
+
+    @Test
+    public void testUseArraySyntaxForQueryParams() {
+        Map<String, Object> props = Collections.singletonMap("use.array.syntax.for.query.values", true);
+        URI uri = new UriBuilderImpl(props).queryParam("foo", "v1", "v2", "v3").build();
+        assertEquals("foo[]=v1&foo[]=v2&foo[]=v3", uri.getQuery());
+    }
+
+    @Test
+    public void testUseArraySyntaxForQueryParamsBuildFromEncodedNormalize() {
+        Map<String, Object> props = Collections.singletonMap("use.array.syntax.for.query.values", true);
+        URI uri = new UriBuilderImpl(props).queryParam("foo", "v1")
+                                           .queryParam("foo", "v2")
+                                           .queryParam("foo", "v3")
+                                           .buildFromEncoded().normalize();
+        assertEquals("foo[]=v1&foo[]=v2&foo[]=v3", uri.getQuery());
+    }
+
     @Path(value = "/TestPath")
     public static class TestPath {
 
@@ -1951,4 +1977,10 @@ public class UriBuilderImplTest {
             .build();
         assertEquals("/%7B", uri.toString());
     }
+    
+    @Test
+    public void invalidUrlsNoHost() {
+        assertThrows(UriBuilderException.class, () -> UriBuilder.fromUri("http://@").build());
+        assertThrows(UriBuilderException.class, () -> UriBuilder.fromUri("http://:@").build());
+    }
 }
\ No newline at end of file
