@@ -92,7 +92,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
 
         actions = new ArrayList<>();
         actions.add(WSSConstants.USERNAMETOKEN);
-        actions.add(XMLSecurityConstants.ENCRYPT);
+        actions.add(XMLSecurityConstants.ENCRYPTION);
         inProperties.setActions(actions);
 
         try {
@@ -142,7 +142,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
         service.getInInterceptors().remove(inhandler);
         inConfig.put(
             ConfigurationConstants.ACTION,
-            ConfigurationConstants.USERNAME_TOKEN + " " + ConfigurationConstants.ENCRYPT
+            ConfigurationConstants.USERNAME_TOKEN + " " + ConfigurationConstants.ENCRYPTION
         );
         inhandler = new WSS4JStaxInInterceptor(inConfig);
         service.getInInterceptors().add(inhandler);
@@ -164,7 +164,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
         WSSSecurityProperties inProperties = new WSSSecurityProperties();
         inProperties.setCallbackHandler(new TestPwdCallback());
         List<WSSConstants.Action> actions = new ArrayList<>();
-        actions.add(XMLSecurityConstants.ENCRYPT);
+        actions.add(XMLSecurityConstants.ENCRYPTION);
         inProperties.setActions(actions);
         Properties cryptoProperties =
             CryptoFactory.getProperties("insecurity.properties", this.getClass().getClassLoader());
@@ -182,7 +182,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
 
         WSSSecurityProperties properties = new WSSSecurityProperties();
         actions = new ArrayList<>();
-        actions.add(XMLSecurityConstants.ENCRYPT);
+        actions.add(XMLSecurityConstants.ENCRYPTION);
         properties.setActions(actions);
         properties.setEncryptionUser("myalias");
         properties.setEncryptionSymAlgorithm(XMLSecurityConstants.NS_XENC_AES128);
@@ -197,7 +197,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
         assertEquals("test", echo.echo("test"));
 
         actions = new ArrayList<>();
-        actions.add(XMLSecurityConstants.ENCRYPT);
+        actions.add(XMLSecurityConstants.ENCRYPTION);
         actions.add(XMLSecurityConstants.SIGNATURE);
         inProperties.setActions(actions);
 
@@ -216,7 +216,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
         Service service = createService();
 
         Map<String, Object> inConfig = new HashMap<>();
-        inConfig.put(ConfigurationConstants.ACTION, ConfigurationConstants.ENCRYPT);
+        inConfig.put(ConfigurationConstants.ACTION, ConfigurationConstants.ENCRYPTION);
         inConfig.put(ConfigurationConstants.PW_CALLBACK_REF, new TestPwdCallback());
         inConfig.put(ConfigurationConstants.DEC_PROP_FILE, "insecurity.properties");
         WSS4JStaxInInterceptor inhandler = new WSS4JStaxInInterceptor(inConfig);
@@ -231,7 +231,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
         client.getOutInterceptors().add(new LoggingOutInterceptor());
 
         Map<String, Object> outConfig = new HashMap<>();
-        outConfig.put(ConfigurationConstants.ACTION, ConfigurationConstants.ENCRYPT);
+        outConfig.put(ConfigurationConstants.ACTION, ConfigurationConstants.ENCRYPTION);
         outConfig.put(ConfigurationConstants.ENCRYPTION_USER, "myalias");
         outConfig.put(ConfigurationConstants.PW_CALLBACK_REF, new TestPwdCallback());
         outConfig.put(ConfigurationConstants.ENC_PROP_FILE, "outsecurity.properties");
@@ -244,7 +244,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
         service.getInInterceptors().remove(inhandler);
         inConfig.put(
             ConfigurationConstants.ACTION,
-            ConfigurationConstants.ENCRYPT + " " + ConfigurationConstants.SIGNATURE
+            ConfigurationConstants.ENCRYPTION + " " + ConfigurationConstants.SIGNATURE
         );
         inhandler = new WSS4JStaxInInterceptor(inConfig);
         service.getInInterceptors().add(inhandler);
@@ -266,7 +266,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
         WSSSecurityProperties inProperties = new WSSSecurityProperties();
         inProperties.setCallbackHandler(new TestPwdCallback());
         List<WSSConstants.Action> actions = new ArrayList<>();
-        actions.add(XMLSecurityConstants.ENCRYPT);
+        actions.add(XMLSecurityConstants.ENCRYPTION);
         actions.add(WSSConstants.USERNAMETOKEN);
         inProperties.setActions(actions);
         Properties cryptoProperties =
@@ -286,7 +286,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
         WSSSecurityProperties properties = new WSSSecurityProperties();
         actions = new ArrayList<>();
         actions.add(WSSConstants.USERNAMETOKEN);
-        actions.add(XMLSecurityConstants.ENCRYPT);
+        actions.add(XMLSecurityConstants.ENCRYPTION);
         properties.setActions(actions);
         properties.addEncryptionPart(
             new SecurePart(new QName(WSSConstants.NS_WSSE10, "UsernameToken"), SecurePart.Modifier.Element)
@@ -313,7 +313,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
         Map<String, Object> inConfig = new HashMap<>();
         inConfig.put(
             ConfigurationConstants.ACTION,
-            ConfigurationConstants.ENCRYPT + " " + ConfigurationConstants.USERNAME_TOKEN
+            ConfigurationConstants.ENCRYPTION + " " + ConfigurationConstants.USERNAME_TOKEN
         );
         inConfig.put(ConfigurationConstants.PW_CALLBACK_REF, new TestPwdCallback());
         inConfig.put(ConfigurationConstants.DEC_PROP_FILE, "insecurity.properties");
@@ -331,7 +331,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
         Map<String, Object> outConfig = new HashMap<>();
         outConfig.put(
             ConfigurationConstants.ACTION,
-            ConfigurationConstants.USERNAME_TOKEN + " " + ConfigurationConstants.ENCRYPT
+            ConfigurationConstants.USERNAME_TOKEN + " " + ConfigurationConstants.ENCRYPTION
         );
         outConfig.put(
             ConfigurationConstants.ENCRYPTION_PARTS,
@@ -392,7 +392,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
 
         actions = new ArrayList<>();
         actions.add(XMLSecurityConstants.SIGNATURE);
-        actions.add(XMLSecurityConstants.ENCRYPT);
+        actions.add(XMLSecurityConstants.ENCRYPTION);
         inProperties.setActions(actions);
 
         try {
@@ -440,7 +440,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
         service.getInInterceptors().remove(inhandler);
         inConfig.put(
             ConfigurationConstants.ACTION,
-            ConfigurationConstants.SIGNATURE + " " + ConfigurationConstants.ENCRYPT
+            ConfigurationConstants.SIGNATURE + " " + ConfigurationConstants.ENCRYPTION
         );
         inhandler = new WSS4JStaxInInterceptor(inConfig);
         service.getInInterceptors().add(inhandler);
@@ -610,7 +610,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
         WSSSecurityProperties inProperties = new WSSSecurityProperties();
         inProperties.setCallbackHandler(new TestPwdCallback());
         List<WSSConstants.Action> actions = new ArrayList<>();
-        actions.add(XMLSecurityConstants.ENCRYPT);
+        actions.add(XMLSecurityConstants.ENCRYPTION);
         actions.add(XMLSecurityConstants.SIGNATURE);
         inProperties.setActions(actions);
         Properties cryptoProperties =
@@ -630,7 +630,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
 
         WSSSecurityProperties properties = new WSSSecurityProperties();
         actions = new ArrayList<>();
-        actions.add(XMLSecurityConstants.ENCRYPT);
+        actions.add(XMLSecurityConstants.ENCRYPTION);
         actions.add(XMLSecurityConstants.SIGNATURE);
         properties.setActions(actions);
         properties.setEncryptionUser("myalias");
@@ -656,7 +656,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
         Map<String, Object> inConfig = new HashMap<>();
         inConfig.put(
             ConfigurationConstants.ACTION,
-            ConfigurationConstants.ENCRYPT + " " + ConfigurationConstants.SIGNATURE
+            ConfigurationConstants.ENCRYPTION + " " + ConfigurationConstants.SIGNATURE
         );
         inConfig.put(ConfigurationConstants.PW_CALLBACK_REF, new TestPwdCallback());
         inConfig.put(ConfigurationConstants.SIG_VER_PROP_FILE, "insecurity.properties");
@@ -675,7 +675,7 @@ public class StaxRoundTripActionTest extends AbstractSecurityTest {
         Map<String, Object> outConfig = new HashMap<>();
         outConfig.put(
             ConfigurationConstants.ACTION,
-            ConfigurationConstants.ENCRYPT + " " + ConfigurationConstants.SIGNATURE
+            ConfigurationConstants.ENCRYPTION + " " + ConfigurationConstants.SIGNATURE
         );
         outConfig.put(ConfigurationConstants.SIGNATURE_USER, "myalias");
         outConfig.put(ConfigurationConstants.ENCRYPTION_USER, "myalias");
